==> haskell-monad-par-extras-0.3.3-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par-extras
version: 0.3.3
id: monad-par-extras-0.3.3-9uJPRq6u2G7Dy6khFdWvSf
key: monad-par-extras-0.3.3-9uJPRq6u2G7Dy6khFdWvSf
license: BSD-3-Clause
copyright: (c) Ryan Newton 2012
maintainer: Ryan Newton <rrnewton@gmail.com>
author: Ryan Newton, Simon Marlow
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.
category: Control,Parallelism,Monads
abi: 44c05c05a526743e07e7892e6c473746
exposed: True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State
hidden-modules: Control.Monad.Par.Pedigree
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-par-extras-0.3.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/monad-par-extras-0.3.3
hs-libraries: HSmonad-par-extras-0.3.3-9uJPRq6u2G7Dy6khFdWvSf
depends:
    base-4.11.1.0 abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj deepseq-1.4.3.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV mtl-2.2.2 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv=3c7ebe7f8f8a713ba55857a5c0914fc8
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock
haddock-html: /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-extras-0.3.3-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par-extras
version: 0.3.3
id: monad-par-extras-0.3.3-L8Gz4t5FuW362xtJ9I9RBD
key: monad-par-extras-0.3.3-L8Gz4t5FuW362xtJ9I9RBD
license: BSD-3-Clause
copyright: (c) Ryan Newton 2012
maintainer: Ryan Newton <rrnewton@gmail.com>
author: Ryan Newton, Simon Marlow
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.
category: Control,Parallelism,Monads
abi: 6881ccd86d77d8eaef337f97521aefff
exposed: True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State
hidden-modules: Control.Monad.Par.Pedigree
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-par-extras-0.3.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/monad-par-extras-0.3.3
hs-libraries: HSmonad-par-extras-0.3.3-L8Gz4t5FuW362xtJ9I9RBD
depends:
    base-4.11.1.0 abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC deepseq-1.4.3.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV mtl-2.2.2 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv=3c7ebe7f8f8a713ba55857a5c0914fc8
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock
haddock-html: /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
